@@ -12,9 +12,9 @@ recluster.boot <- function (tree,mat,phylo=NULL,tr=100,p=0.5,dist="simpson", met
 		}
 		treesb[[i]]<-recluster.cons(xs,phylo,tr,p,dist)$cons
 	}
-	btr2 <- .compressTipLabel(treesb)
+	btr2 <- .recluster_compressTipLabel(treesb)
 	tr2 <- recluster.check(tree, attr(btr2, "TipLabel"))
-	btr2 <- .uncompressTipLabel(btr2)
+	btr2 <- .recluster_uncompressTipLabel(btr2)
 	result <- prop.clades(tr2, btr2, rooted=T)*(100/boot)
 	rows<-nrow(mat)
 	matrix<-dist.nodes(tree)[(rows+1):(rows*2-1),(rows+1):(rows*2-1)]
